Hi Aaron,

thanks for the tip with (org-element-property :value X). I also got rid
of the let*. Actually, the previous patch is buggy and I've thought had
submitted another patch to fix that. But unfortunately it seems it got
lost in the interwebs.

Best wishes,
Sebastian

>From a814380158de6185747975848533e3bd6e675afd Mon Sep 17 00:00:00 2001
From: Sebastian Christ <rudolfo.chr...@gmail.com>
Date: Thu, 12 Nov 2015 19:23:05 +0100
Subject: [PATCH] ox-extra.el: Fix filtering of latex header blocks

* contrib/lisp/ox-extra.el (org-latex-header-blocks-filter): Use `org-element' API to
  find beginning, end and contents of latex header blocks.

`org-latex-header-blocks-filter' still called
`org-edit-src-find-region-and-lang' and raised an undefined function
error because the funtion was removed from org-mode. This is fixed by determining the
begin and end of the latex block via `org-element'.
---
 contrib/lisp/ox-extra.el | 29 ++++++++++++-----------------
 1 file changed, 12 insertions(+), 17 deletions(-)

diff --git a/contrib/lisp/ox-extra.el b/contrib/lisp/ox-extra.el
index e6d45cc..232f623 100644
--- a/contrib/lisp/ox-extra.el
+++ b/contrib/lisp/ox-extra.el
@@ -60,7 +60,7 @@
 
 (defun org-latex-header-blocks-filter (backend)
   (when (org-export-derived-backend-p backend 'latex)
-    (let ((positions
+    (let ((blocks
 	   (org-element-map (org-element-parse-buffer 'greater-element nil) 'export-block
 	     (lambda (block)
 	       (when (and (string= (org-element-property :type block) "LATEX")
@@ -69,23 +69,18 @@
 				   "yes"))
 		 (list (org-element-property :begin block)
 		       (org-element-property :end block)
-		       (org-element-property :post-affiliated block)))))))
-      (mapc (lambda (pos)
-	      (goto-char (nth 2 pos))
-	      (destructuring-bind
-		  (beg end &rest ignore)
-		  (org-edit-src-find-region-and-lang)
-		(let ((contents-lines (split-string
-				       (buffer-substring-no-properties beg end)
-				       "\n")))
-		  (delete-region (nth 0 pos) (nth 1 pos))
-		  (dolist (line contents-lines)
-		    (insert (concat "#+latex_header: "
-				    (replace-regexp-in-string "\\` *" "" line)
-				    "\n"))))))
-	    ;; go in reverse, to avoid wrecking the numeric positions
+		       (org-element-property :value block)))))))
+      (mapc (lambda (block)
+	      (goto-char (nth 0 block))
+	      (let ((contents-lines (split-string (nth 2 block) "\n" t)))
+                (delete-region (nth 0 block) (nth 1 block))
+                (dolist (line contents-lines)
+                  (insert (concat "#+latex_header: "
+                                  (replace-regexp-in-string "\\` *" "" line)
+                                  "\n")))))
+	    ;; go in reverse, to avoid wrecking the numeric blocks
 	    ;; earlier in the file
-	    (reverse positions)))))
+	    (reverse blocks)))))
 
 
 ;; During export headlines which have the "ignore" tag are removed
-- 
2.6.3

Reply via email to